"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import preemo.gen.models.registered_function_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RegisterFunctionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_TO_REGISTER_FIELD_NUMBER: builtins.int
    @property
    def function_to_register(self) -> preemo.gen.models.registered_function_pb2.RegisteredFunction: ...
    def __init__(
        self,
        *,
        function_to_register: preemo.gen.models.registered_function_pb2.RegisteredFunction | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_function_to_register", b"_function_to_register", "function_to_register", b"function_to_register"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_function_to_register", b"_function_to_register", "function_to_register", b"function_to_register"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_function_to_register", b"_function_to_register"]) -> typing_extensions.Literal["function_to_register"] | None: ...

global___RegisterFunctionRequest = RegisterFunctionRequest

@typing_extensions.final
class RegisterFunctionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RegisterFunctionResponse = RegisterFunctionResponse
